3D contourf polygons placed between levels
------------------------------------------
The polygons used in a 3D `~.Axes3D.contourf` plot are
now placed halfway between the contour levels, as each polygon represents the
location of values that lie between two levels.
